@@ -3,6 +3,9 @@
 #define GLOBAL_H
 #include <time.h>
 
+#define VERSION_STRING	"EnderUNIX Isoqlog 2.2"
+
+
 enum {
         BUFSIZE = 1024,
         KEYSIZE = 64,
@@ -11,12 +14,10 @@ enum {
 
 time_t secs;
 time_t today ;
-struct tm *t;
 struct tm *t2;
 
 
 
 
+
 #endif
-
-
