@@ -26,7 +26,7 @@ int main(int argc, char **argv)
 	while (!error && (c = getopt(argc,argv,"f:hv")) != -1) {
         	switch (c) {
         	case 'v':
-			puts("EnderUNIX Isoqlog 2.1.1");
+			puts(VERSION_STRING);
 	        	exit(0);
 	        	break;
 		case 'h':
@@ -70,10 +70,6 @@ int main(int argc, char **argv)
         if (strcmp(logtype, "exim") == 0)
 		readEximLogFile(logstore);
 
-
-
 	createHtml();
-
 	return 0;
 }
-
